from nonebot import on_command
from nonebot.rule import to_me
from nonebot.adapters.cqhttp import Bot, Event

from .data_source import sim_draw

fgo_draw = on_command("Fgo_Draw", aliases={
                      "FGO抽卡", "FGO来一单", "fgo抽卡", "fgo来一单", "Fgo抽卡", "Fgo来一单"}, rule=to_me())


@fgo_draw.handle()
async def fgo_draw_handler(bot: Bot, event: Event):
    args = str(event.get_message()).strip()
    noimg = True
    if args == "图":
        noimg = False
    msgs = sim_draw(55, noimg=noimg, game="fgo")
    for msg in msgs:
        await fgo_draw.send(msg)

prts_draw = on_command("Prts_Draw", aliases={
                       "明日方舟抽卡", "明日方舟来一单", "方舟抽卡", "方舟来一单"}, rule=to_me())


@prts_draw.handle()
async def prts_draw_handler(bot: Bot, event: Event):
    args = str(event.get_message()).strip()
    noimg = True
    if args == "图":
        noimg = False
    msgs = sim_draw(55, noimg=noimg, game="prts")
    for msg in msgs:
        await prts_draw.send(msg)



import os
import random
import nonebot
import ujson as json
from nonebot.adapters.cqhttp import MessageSegment

driver: nonebot.Driver = nonebot.get_driver()
cachepath: str
config: dict


def draw(times: int, game: str):
    with open(os.path.join(cachepath, config["%scards" % game]), "r") as f:
        cards = json.load(f)
    cardlist = [[] for _ in range(len(config[game]))]
    for card in cards:
        for i in range(len(cardlist)):
            if card["star"] == config[game][i][1]:
                cardlist[i].append(card)
    rlist = [[] for _ in range(len(config[game]))]
    for _ in range(times):
        i = random.random()
        for j in range(len(rlist)):
            if i < config[game][j][0]:
                rlist[j].append(random.choice(cardlist[j]))
    return rlist


def build_msg(gets: list, msgs: list):
    msg = ""
    for i in range(len(gets)):
        if not gets[i]:
            msg = msg + msgs[i] + "无\n"
        else:
            msg += msgs[i]
            for s in gets[i]:
                msg = msg + s["name"] + " "
            msg += "\n"
    return [msg[:-1]]


def build_imgmsg(gets: list, msgs: list):
    msg = ""
    for i in range(len(gets)):
        if not gets[i]:
            msg = msg + msgs[i] + "无\n"
        else:
            msg += msgs[i]
            for s in gets[i]:
                msg = msg + MessageSegment.image(file=s["url"])
            msg += "\n"
    return [msg[:-1]]


def sim_draw(times: int, game: str, noimg=True):
    if noimg:
        return build_msg(draw(times, game), config["%smsgs" % game])
    else:
        return build_imgmsg(draw(times, game), config["%smsgs" % game])


@driver.on_startup
async def check_data():
    global cachepath, config
    cachepath = os.path.join(os.getcwd(), "cache", "simdraw")
    try:
        with open(os.path.join(cachepath, "config.json"), "r") as f:
            config = json.load(f)
        nonebot.require("nonebot_plugin_simdraw").draw = sim_draw
        nonebot.logger.info("simdraw init success")
    except:
        nonebot.logger.info("config.json not found")



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['nonebot_plugin_simdraw']

package_data = \
{'': ['*']}

install_requires = \
['nonebot2>=2.0.0-alpha.8,<3.0.0', 'ujson>=4.0.1,<5.0.0']

setup_kwargs = {
    'name': 'nonebot-plugin-simdraw',
    'version': '0.1.2',
    'description': 'A phonegame draw simulator plugin for nonebot2',
    'long_description': '<h1 align="center">nonebot-plugin-simdraw</h1>\n\n## 使用方式\n\n- 方式一：\n\n发送`[gamename]抽卡（来一发）`来模拟手游抽卡（目前仅有Fgo与明日方舟卡池文件、欢迎提交其他游戏卡池文件娱乐大家~）\n\n指令后带参数`图`可以抽卡附带你们老婆们和老公们的头像\n\n- 方式二：\n\n使用以下方式调用抽卡函数\n\n```python\nnonebot.require("nonebot_plugin_simdraw").draw(times: int, game: str, noimg=True):\n    return [Messages]\n```\n\n## 配置项\n\n使用本插件需要将在bot.py同级目录下新建/cache/simdraw文件夹，并在文件夹内配置congfig.json与其他游戏卡池信息文件\n\ncongfig.json范例：\n\n```json\n{\n    "fgo": [         //游戏名\n        [0.01,5],    //[概率,类别]\n        [0.03,4],\n        [0.04,-1]\n    ],\n    "fgomsgs": [     //游戏名+msgs\n        "五星从者：", //用于生成抽卡信息\n        "四星从者：",\n        "五星礼装："\n    ],\n    "fgocards": "fgo.json" //游戏名+cards:卡池信息文件名\n}\n```\n\n游戏卡池信息文件范例：\n\n```json\n[\n    {\n        "name": "\\u5f17\\u6817\\u591a",   //角色名\n        "url": "https:\\/\\/fgo.wiki\\/images\\/3\\/3e\\/Servant300.jpg", //图片url\n        "star": 5  //类别\n    }\n]\n```\n\n本仓库内有fgo与明日方舟的卡池文件与配置文件，欢迎取用~',
    'author': 'abrahumlink',
    'author_email': '307887491@qq.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/abrahum/nonebot_plugin_simdraw',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
